import pickle
import configparser
import config

# INDEXED TAG OF TRAINED CORPUS
def get_POS_TAGS_index():
    # Load the pickle file
    with open(config.postagsindex_pkl_filepath, "rb") as f:
        tagindex_model = pickle.load(f)
    
    # file = 'config.ini'
    # config = configparser.ConfigParser()
    # config.read(file)

    # postagsindex_pkl_filepath = config['PATHS']['postagsindex_pkl_filepath']

    # with open(postagsindex_pkl_filepath, "rb") as f:
    #     tagindex_model = pickle.load(f)
        
    return tagindex_model

get_POS_TAGS_index()


import pickle
import configparser
import config

# VOCABULARY OF THE MODEL
def get_VOCAB_model():
    with open(config.vocabs_pkl_filepath, "rb") as f:
        vocab_model = pickle.load(f)
    
    # file = 'config.ini'
    # config = configparser.ConfigParser()
    # config.read(file)

    # vocabs_pkl_filepath = config['PATHS']['vocabs_pkl_filepath']

    # with open(vocabs_pkl_filepath, "rb") as f:
    #     vocab_model = pickle.load(f)
    
    return vocab_model

get_VOCAB_model()


import pandas as pd
import configparser
import config


# GET CORPUS
def cebuano_corpus():
    ceb_corpus = pd.read_csv(config.corpus_csv_filepath)
    
    # file = 'config.ini'
    # config = configparser.ConfigParser()
    # config.read(file)

    # corpus_csv_filepath = config['PATHS']['corpus_csv_filepath']

    # corpus_csv_filepath = pd.read_csv(corpus_csv_filepath)
    
    return ceb_corpus

cebuano_corpus()